@@ -46,6 +46,9 @@ TERM_STARTS = {
     (2012, 3): date(2012, 9, 30),
     (2013, 1): date(2013, 1, 6),
     (2013, 2): date(2013, 4, 14),
+    (2013, 3): date(2013, 10, 6),
+    (2014, 1): date(2014, 1, 12),
+    (2014, 2): date(2014, 4, 20),  # Easter Sunday?
 }
 
 OFFSET_TERM_STARTS = dict((k,v-timedelta(14)) for k,v in TERM_STARTS.items())
@@ -87,6 +90,7 @@ def ox_date_dict(dt=None):
     year, term, week, day = normal_to_ox(dt)
     return {
         'day_name': DAY_NAMES[day],
+        'day_name_short': DAY_NAMES[day][:3],
         'day': day,
         'week': week,
         'ordinal': 'th' if 10<week<20 else {1:'st',2:'nd',3:'rd'}.get(abs(week)%10, 'th'),
@@ -96,6 +100,7 @@ def ox_date_dict(dt=None):
         'year': year,
         'day_number': dt.day,
         'month': dt.strftime('%b'),
+        'month_long': dt.strftime('%B'),
     }
 
 def format_today():
